@@ -11,20 +11,27 @@
 use strict;
 use FindBin;
 use lib "$FindBin::Bin/../lib";
-use Term::ProgressBar;
 use YAML qw(:all);
 use File::Spec::Functions qw(catfile);
-
 use Module::CPANTS::Generator;
+use IO::Capture::Stderr;
+
 my $class="Module::CPANTS::Generator";
 $class->setup_dirs;
 $class->load_generators;
 
+print "analyse_dists.pl\n".('#'x66)."\n";
+
 opendir(DIR,$class->distsdir) || die "$!";
 my @files=grep {!/^\./} readdir(DIR);
 
 # list of all active dists
-my $dists=LoadFile('dists.yml');
+my $distfile=catfile($class->distsdir,'dists.yml');
+my $dists;
+if (-e $distfile) {
+    $dists=LoadFile($distfile);
+}
+my %errors;
 
 # get list of metrics, some might be outdated
 my %old_metrics;
@@ -33,53 +40,62 @@ while (my $f=readdir(MET)) {
     chomp($f);
     next if $f=~/^\./;
     next if $f eq 'README';
+    next if $f eq 'dists.yml';
     $old_metrics{$f}=1;
 }
 
-
-my $progress=Term::ProgressBar->new({
-				     name=>'Analyse Dists   ',
-				     count=>scalar keys %$dists,
-				    }) unless $class->conf->no_bar;
-
 my $cpants_version=$Module::CPANTS::Generator::VERSION;
-
 my $id=1;
 
-while (my($f,$status)=each(%$dists)) {
+foreach my $f (sort keys %$dists) {
+    my $status=$dists->{$f};
     next if $f=~/^\./;
     chomp($f);
 
-    $progress->update() unless $class->conf->no_bar;
-    next unless (-e catfile($class->distsdir,$f));
+    unless (-e catfile($class->distsdir,$f)) {
+        #    print "dist not in distdir: $f\n";
+        next;
+    };
 
     my $cpants=$class->new($f);
     my $metricfile=$cpants->metricfile;
     delete $old_metrics{$cpants->dist.'.yml'};
 
-    print $cpants->package,"\n" if $cpants->conf->no_bar;
+    print "analyse ".$cpants->package."\n";
 
     if ($status eq 'old' && -e $metricfile && !$cpants->conf->force) {
-	my $oldmetric=LoadFile($metricfile);
-	my $generated_with=$oldmetric->{generated_with};
-	$generated_with=~s/[^\.\d]//g;
-#	print "generated $generated_with\n";
-	next if $generated_with eq $cpants_version;
+        my $oldmetric=$class->read_yaml($metricfile);
+        my $generated_with=$oldmetric->{generated_with};
+        $generated_with=~s/[^\.\d]//g;
+        if ($generated_with eq $cpants_version) {
+            print "\tup to date, skip\n";
+            next;
+        }
 	unlink($metricfile);
 
     } elsif ($status eq 'del') {
-	unlink($metricfile);
-	next;
+        print "\tnot on CPAN anymore, delete\n";
+        unlink($metricfile);
+        next;
     }
 
-
+    my $capture = IO::Capture::Stderr->new();
+    $capture->start();   
+    
     foreach my $generator (@{$cpants->available_generators}) {
-	print "+ $generator\n" if $cpants->conf->no_bar;
-	$generator->analyse($cpants);
-	last if $cpants->abort;
+        #print "\t+ $generator\n";
+        $generator->analyse($cpants);
+        last if $cpants->abort;
     }
-
+    $capture->stop;
+    my $err=join('',$capture->read);
+    if ($err) {
+        print $err;
+        $errors{$f}=$err;
+    }
+    
     $cpants->{metric}{id}=$id;
+    $cpants->{metric}{cpants_errors}=$err;
     $id++;
 
     $cpants->write_metric;
@@ -89,10 +105,12 @@ while (my($f,$status)=each(%$dists)) {
 
 # delete old metrics
 foreach my $del (keys %old_metrics) {
-    print "purge $del\n" if $class->conf->no_bar;
+    print "$del\n\tnot on CPAN anymore, delete\n";
     unlink(catfile($class->metricdir,$del));
 }
 
+# write errors
+DumpFile(catfile($FindBin::Bin,'errors.yaml'),\%errors);
 
 __END__
 
